# tpyfilestructure

Python package to read and display segregated file names present in a directory based on type of the file. 

# Installation

You can install tpyfilestructure from [PyPI](https://pypi.org/project/tpyfilestructure/)
```python
pip install tpyfilestructure
```

# How to use
Navigate to the directory from where the file structure should be displayed. Open Command Prompt(cmd)/powershell in the same path. Once the Command Prompt/powershell pops up just type 'tpyfilestructure' and hit enter. 

    $ tpyfilestructure
    --displays categorized file names based on type--

